#ifndef QT_WAYLAND_SERVER_GREENISLAND_OUTPUTMANAGEMENT
#define QT_WAYLAND_SERVER_GREENISLAND_OUTPUTMANAGEMENT

#include "wayland-server.h"
#include "wayland-greenisland-outputmanagement-server-protocol.h"
#include <QByteArray>
#include <QMultiMap>
#include <QString>

#ifndef WAYLAND_VERSION_CHECK
#define WAYLAND_VERSION_CHECK(major, minor, micro) \
    ((WAYLAND_VERSION_MAJOR > (major)) || \
    (WAYLAND_VERSION_MAJOR == (major) && WAYLAND_VERSION_MINOR > (minor)) || \
    (WAYLAND_VERSION_MAJOR == (major) && WAYLAND_VERSION_MINOR == (minor) && WAYLAND_VERSION_MICRO >= (micro)))
#endif

QT_BEGIN_NAMESPACE

namespace QtWaylandServer {
    class  greenisland_outputmanagement
    {
    public:
        greenisland_outputmanagement(struct ::wl_client *client, int id, int version);
        greenisland_outputmanagement(struct ::wl_display *display, int version);
        greenisland_outputmanagement(struct ::wl_resource *resource);
        greenisland_outputmanagement();

        virtual ~greenisland_outputmanagement();

        class Resource
        {
        public:
            Resource() : outputmanagement_object(0), handle(0) {}
            virtual ~Resource() {}

            greenisland_outputmanagement *outputmanagement_object;
            struct ::wl_resource *handle;

            struct ::wl_client *client() const { return handle->client; }
            int version() const { return wl_resource_get_version(handle); }

            static Resource *fromResource(struct ::wl_resource *resource);
        };

        void init(struct ::wl_client *client, int id, int version);
        void init(struct ::wl_display *display, int version);
        void init(struct ::wl_resource *resource);

        Resource *add(struct ::wl_client *client, int version);
        Resource *add(struct ::wl_client *client, int id, int version);
        Resource *add(struct wl_list *resource_list, struct ::wl_client *client, int id, int version);

        Resource *resource() { return m_resource; }
        const Resource *resource() const { return m_resource; }

        QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
        const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }

        bool isGlobal() const { return m_global != 0; }
        bool isResource() const { return m_resource != 0; }

        static const struct ::wl_interface *interface();
        static QByteArray interfaceName() { return interface()->name; }
        static int interfaceVersion() { return interface()->version; }


    protected:
        virtual Resource *outputmanagement_allocate();

        virtual void outputmanagement_bind_resource(Resource *resource);
        virtual void outputmanagement_destroy_resource(Resource *resource);

        virtual void outputmanagement_create_configuration(Resource *resource, uint32_t id);

    private:
        static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
        static void destroy_func(struct ::wl_resource *client_resource);

        Resource *bind(struct ::wl_client *client, uint32_t id, int version);
        Resource *bind(struct ::wl_resource *handle);

        static const struct ::greenisland_outputmanagement_interface m_greenisland_outputmanagement_interface;

        static void handle_create_configuration(
            ::wl_client *client,
            struct wl_resource *resource,
            uint32_t id);

        QMultiMap<struct ::wl_client*, Resource*> m_resource_map;
        Resource *m_resource;
        struct ::wl_global *m_global;
        uint32_t m_globalVersion;
    };

    class  greenisland_outputconfiguration
    {
    public:
        greenisland_outputconfiguration(struct ::wl_client *client, int id, int version);
        greenisland_outputconfiguration(struct ::wl_display *display, int version);
        greenisland_outputconfiguration(struct ::wl_resource *resource);
        greenisland_outputconfiguration();

        virtual ~greenisland_outputconfiguration();

        class Resource
        {
        public:
            Resource() : outputconfiguration_object(0), handle(0) {}
            virtual ~Resource() {}

            greenisland_outputconfiguration *outputconfiguration_object;
            struct ::wl_resource *handle;

            struct ::wl_client *client() const { return handle->client; }
            int version() const { return wl_resource_get_version(handle); }

            static Resource *fromResource(struct ::wl_resource *resource);
        };

        void init(struct ::wl_client *client, int id, int version);
        void init(struct ::wl_display *display, int version);
        void init(struct ::wl_resource *resource);

        Resource *add(struct ::wl_client *client, int version);
        Resource *add(struct ::wl_client *client, int id, int version);
        Resource *add(struct wl_list *resource_list, struct ::wl_client *client, int id, int version);

        Resource *resource() { return m_resource; }
        const Resource *resource() const { return m_resource; }

        QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
        const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }

        bool isGlobal() const { return m_global != 0; }
        bool isResource() const { return m_resource != 0; }

        static const struct ::wl_interface *interface();
        static QByteArray interfaceName() { return interface()->name; }
        static int interfaceVersion() { return interface()->version; }


        void send_applied();
        void send_applied(struct ::wl_resource *resource);
        void send_failed();
        void send_failed(struct ::wl_resource *resource);

    protected:
        virtual Resource *outputconfiguration_allocate();

        virtual void outputconfiguration_bind_resource(Resource *resource);
        virtual void outputconfiguration_destroy_resource(Resource *resource);

        virtual void outputconfiguration_enable(Resource *resource, struct ::wl_resource *output, int32_t enable);
        virtual void outputconfiguration_primary(Resource *resource, struct ::wl_resource *output, int32_t primary);
        virtual void outputconfiguration_mode(Resource *resource, struct ::wl_resource *output, int32_t mode_id);
        virtual void outputconfiguration_transform(Resource *resource, struct ::wl_resource *output, int32_t transform);
        virtual void outputconfiguration_position(Resource *resource, struct ::wl_resource *output, int32_t x, int32_t y);
        virtual void outputconfiguration_scale(Resource *resource, struct ::wl_resource *output, int32_t scale);
        virtual void outputconfiguration_apply(Resource *resource);

    private:
        static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
        static void destroy_func(struct ::wl_resource *client_resource);

        Resource *bind(struct ::wl_client *client, uint32_t id, int version);
        Resource *bind(struct ::wl_resource *handle);

        static const struct ::greenisland_outputconfiguration_interface m_greenisland_outputconfiguration_interface;

        static void handle_enable(
            ::wl_client *client,
            struct wl_resource *resource,
            struct ::wl_resource *output,
            int32_t enable);
        static void handle_primary(
            ::wl_client *client,
            struct wl_resource *resource,
            struct ::wl_resource *output,
            int32_t primary);
        static void handle_mode(
            ::wl_client *client,
            struct wl_resource *resource,
            struct ::wl_resource *output,
            int32_t mode_id);
        static void handle_transform(
            ::wl_client *client,
            struct wl_resource *resource,
            struct ::wl_resource *output,
            int32_t transform);
        static void handle_position(
            ::wl_client *client,
            struct wl_resource *resource,
            struct ::wl_resource *output,
            int32_t x,
            int32_t y);
        static void handle_scale(
            ::wl_client *client,
            struct wl_resource *resource,
            struct ::wl_resource *output,
            int32_t scale);
        static void handle_apply(
            ::wl_client *client,
            struct wl_resource *resource);

        QMultiMap<struct ::wl_client*, Resource*> m_resource_map;
        Resource *m_resource;
        struct ::wl_global *m_global;
        uint32_t m_globalVersion;
    };
}

QT_END_NAMESPACE

#endif
