#ifndef QT_WAYLAND_SERVER_GREENISLAND_SCREENSHOOTER
#define QT_WAYLAND_SERVER_GREENISLAND_SCREENSHOOTER

#include "wayland-server.h"
#include "wayland-greenisland-screenshooter-server-protocol.h"
#include <QByteArray>
#include <QMultiMap>
#include <QString>

#ifndef WAYLAND_VERSION_CHECK
#define WAYLAND_VERSION_CHECK(major, minor, micro) \
    ((WAYLAND_VERSION_MAJOR > (major)) || \
    (WAYLAND_VERSION_MAJOR == (major) && WAYLAND_VERSION_MINOR > (minor)) || \
    (WAYLAND_VERSION_MAJOR == (major) && WAYLAND_VERSION_MINOR == (minor) && WAYLAND_VERSION_MICRO >= (micro)))
#endif

QT_BEGIN_NAMESPACE

namespace QtWaylandServer {
    class  greenisland_screenshooter
    {
    public:
        greenisland_screenshooter(struct ::wl_client *client, int id, int version);
        greenisland_screenshooter(struct ::wl_display *display, int version);
        greenisland_screenshooter(struct ::wl_resource *resource);
        greenisland_screenshooter();

        virtual ~greenisland_screenshooter();

        class Resource
        {
        public:
            Resource() : screenshooter_object(0), handle(0) {}
            virtual ~Resource() {}

            greenisland_screenshooter *screenshooter_object;
            struct ::wl_resource *handle;

            struct ::wl_client *client() const { return handle->client; }
            int version() const { return wl_resource_get_version(handle); }

            static Resource *fromResource(struct ::wl_resource *resource);
        };

        void init(struct ::wl_client *client, int id, int version);
        void init(struct ::wl_display *display, int version);
        void init(struct ::wl_resource *resource);

        Resource *add(struct ::wl_client *client, int version);
        Resource *add(struct ::wl_client *client, int id, int version);
        Resource *add(struct wl_list *resource_list, struct ::wl_client *client, int id, int version);

        Resource *resource() { return m_resource; }
        const Resource *resource() const { return m_resource; }

        QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
        const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }

        bool isGlobal() const { return m_global != 0; }
        bool isResource() const { return m_resource != 0; }

        static const struct ::wl_interface *interface();
        static QByteArray interfaceName() { return interface()->name; }
        static int interfaceVersion() { return interface()->version; }


        enum effects {
            effects_pointer = 1, // include the pointer
            effects_border = 2 // include the window border
        };

    protected:
        virtual Resource *screenshooter_allocate();

        virtual void screenshooter_bind_resource(Resource *resource);
        virtual void screenshooter_destroy_resource(Resource *resource);

        virtual void screenshooter_capture_output(Resource *resource, uint32_t id, struct ::wl_resource *output, wl_array *effects);
        virtual void screenshooter_capture_active(Resource *resource, uint32_t id, wl_array *effects);
        virtual void screenshooter_capture_surface(Resource *resource, uint32_t id, wl_array *effects);
        virtual void screenshooter_capture_area(Resource *resource, uint32_t id, wl_array *effects);

    private:
        static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
        static void destroy_func(struct ::wl_resource *client_resource);

        Resource *bind(struct ::wl_client *client, uint32_t id, int version);
        Resource *bind(struct ::wl_resource *handle);

        static const struct ::greenisland_screenshooter_interface m_greenisland_screenshooter_interface;

        static void handle_capture_output(
            ::wl_client *client,
            struct wl_resource *resource,
            uint32_t id,
            struct ::wl_resource *output,
            wl_array *effects);
        static void handle_capture_active(
            ::wl_client *client,
            struct wl_resource *resource,
            uint32_t id,
            wl_array *effects);
        static void handle_capture_surface(
            ::wl_client *client,
            struct wl_resource *resource,
            uint32_t id,
            wl_array *effects);
        static void handle_capture_area(
            ::wl_client *client,
            struct wl_resource *resource,
            uint32_t id,
            wl_array *effects);

        QMultiMap<struct ::wl_client*, Resource*> m_resource_map;
        Resource *m_resource;
        struct ::wl_global *m_global;
        uint32_t m_globalVersion;
    };

    class  greenisland_screenshot
    {
    public:
        greenisland_screenshot(struct ::wl_client *client, int id, int version);
        greenisland_screenshot(struct ::wl_display *display, int version);
        greenisland_screenshot(struct ::wl_resource *resource);
        greenisland_screenshot();

        virtual ~greenisland_screenshot();

        class Resource
        {
        public:
            Resource() : screenshot_object(0), handle(0) {}
            virtual ~Resource() {}

            greenisland_screenshot *screenshot_object;
            struct ::wl_resource *handle;

            struct ::wl_client *client() const { return handle->client; }
            int version() const { return wl_resource_get_version(handle); }

            static Resource *fromResource(struct ::wl_resource *resource);
        };

        void init(struct ::wl_client *client, int id, int version);
        void init(struct ::wl_display *display, int version);
        void init(struct ::wl_resource *resource);

        Resource *add(struct ::wl_client *client, int version);
        Resource *add(struct ::wl_client *client, int id, int version);
        Resource *add(struct wl_list *resource_list, struct ::wl_client *client, int id, int version);

        Resource *resource() { return m_resource; }
        const Resource *resource() const { return m_resource; }

        QMultiMap<struct ::wl_client*, Resource*> resourceMap() { return m_resource_map; }
        const QMultiMap<struct ::wl_client*, Resource*> resourceMap() const { return m_resource_map; }

        bool isGlobal() const { return m_global != 0; }
        bool isResource() const { return m_resource != 0; }

        static const struct ::wl_interface *interface();
        static QByteArray interfaceName() { return interface()->name; }
        static int interfaceVersion() { return interface()->version; }


        enum error {
            error_bad_buffer = 0 // Buffer doesn't match requirements
        };

        void send_setup(int32_t width, int32_t height, int32_t stride, int32_t format);
        void send_setup(struct ::wl_resource *resource, int32_t width, int32_t height, int32_t stride, int32_t format);
        void send_done();
        void send_done(struct ::wl_resource *resource);
        void send_failed(int32_t error);
        void send_failed(struct ::wl_resource *resource, int32_t error);

    protected:
        virtual Resource *screenshot_allocate();

        virtual void screenshot_bind_resource(Resource *resource);
        virtual void screenshot_destroy_resource(Resource *resource);

        virtual void screenshot_destroy(Resource *resource);
        virtual void screenshot_record(Resource *resource, struct ::wl_resource *buffer);

    private:
        static void bind_func(struct ::wl_client *client, void *data, uint32_t version, uint32_t id);
        static void destroy_func(struct ::wl_resource *client_resource);

        Resource *bind(struct ::wl_client *client, uint32_t id, int version);
        Resource *bind(struct ::wl_resource *handle);

        static const struct ::greenisland_screenshot_interface m_greenisland_screenshot_interface;

        static void handle_destroy(
            ::wl_client *client,
            struct wl_resource *resource);
        static void handle_record(
            ::wl_client *client,
            struct wl_resource *resource,
            struct ::wl_resource *buffer);

        QMultiMap<struct ::wl_client*, Resource*> m_resource_map;
        Resource *m_resource;
        struct ::wl_global *m_global;
        uint32_t m_globalVersion;
    };
}

QT_END_NAMESPACE

#endif
