/* Generated by wayland-scanner 1.12.0 */

#ifndef GREENISLAND_OUTPUTMANAGEMENT_SERVER_PROTOCOL_H
#define GREENISLAND_OUTPUTMANAGEMENT_SERVER_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

#ifdef  __cplusplus
extern "C" {
#endif

struct wl_client;
struct wl_resource;

/**
 * @page page_greenisland_outputmanagement The greenisland_outputmanagement protocol
 * @section page_ifaces_greenisland_outputmanagement Interfaces
 * - @subpage page_iface_greenisland_outputmanagement - creates an output configuration to be applied later
 * - @subpage page_iface_greenisland_outputconfiguration - output configuration
 * @section page_copyright_greenisland_outputmanagement Copyright
 * <pre>
 *
 *
 * Copyright (C) 2016 Pier Luigi Fiorini <pierluigi.fiorini@gmail.com>
 * Copyright (C) 2015 Sebastian Kügler <sebas@kde.org>
 *
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that the above copyright notice appear in
 * all copies and that both that copyright notice and this permission
 * notice appear in supporting documentation, and that the name of
 * the copyright holders not be used in advertising or publicity
 * pertaining to distribution of the software without specific,
 * written prior permission.  The copyright holders make no
 * representations about the suitability of this software for any
 * purpose.  It is provided "as is" without express or implied
 * warranty.
 *
 * THE COPYRIGHT HOLDERS DISCLAIM ALL WARRANTIES WITH REGARD TO THIS
 * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 * THIS SOFTWARE.
 *
 * </pre>
 */
struct greenisland_outputconfiguration;
struct greenisland_outputmanagement;
struct wl_output;

/**
 * @page page_iface_greenisland_outputmanagement greenisland_outputmanagement
 * @section page_iface_greenisland_outputmanagement_desc Description
 *
 * The greenisland_outputmanagement global object allows clients to create
 * a configuration for one or more outputs to be applied later.
 * @section page_iface_greenisland_outputmanagement_api API
 * See @ref iface_greenisland_outputmanagement.
 */
/**
 * @defgroup iface_greenisland_outputmanagement The greenisland_outputmanagement interface
 *
 * The greenisland_outputmanagement global object allows clients to create
 * a configuration for one or more outputs to be applied later.
 */
extern const struct wl_interface greenisland_outputmanagement_interface;
/**
 * @page page_iface_greenisland_outputconfiguration greenisland_outputconfiguration
 * @section page_iface_greenisland_outputconfiguration_desc Description
 *
 * This is a set of configuration changes for one or more outputs.
 *
 * Clients call requests on this resource in order to enable, set as primary,
 * change mode, change transform, move and change scaling factor of
 * one or more outputs. Once all attributes are configured, the
 * client asks the compositor to apply all changesets calling the
 * apply request. At this point the compositor signals back whether all
 * changesets applied successfully or failed to apply.
 * @section page_iface_greenisland_outputconfiguration_api API
 * See @ref iface_greenisland_outputconfiguration.
 */
/**
 * @defgroup iface_greenisland_outputconfiguration The greenisland_outputconfiguration interface
 *
 * This is a set of configuration changes for one or more outputs.
 *
 * Clients call requests on this resource in order to enable, set as primary,
 * change mode, change transform, move and change scaling factor of
 * one or more outputs. Once all attributes are configured, the
 * client asks the compositor to apply all changesets calling the
 * apply request. At this point the compositor signals back whether all
 * changesets applied successfully or failed to apply.
 */
extern const struct wl_interface greenisland_outputconfiguration_interface;

/**
 * @ingroup iface_greenisland_outputmanagement
 * @struct greenisland_outputmanagement_interface
 */
struct greenisland_outputmanagement_interface {
	/**
	 * create a new output configuration
	 *
	 * Request an output configuration, which can be changed and then
	 * applied.
	 */
	void (*create_configuration)(struct wl_client *client,
				     struct wl_resource *resource,
				     uint32_t id);
};


/**
 * @ingroup iface_greenisland_outputmanagement
 */
#define GREENISLAND_OUTPUTMANAGEMENT_CREATE_CONFIGURATION_SINCE_VERSION 1

/**
 * @ingroup iface_greenisland_outputconfiguration
 * @struct greenisland_outputconfiguration_interface
 */
struct greenisland_outputconfiguration_interface {
	/**
	 * enable or disable an output
	 *
	 * Mark the output as enabled or disabled.
	 * @param enable request to enable or disable this output
	 */
	void (*enable)(struct wl_client *client,
		       struct wl_resource *resource,
		       struct wl_resource *output,
		       int32_t enable);
	/**
	 * set an output as primary or secondary
	 *
	 * Mark the output as primary or secondary. Shell panels and
	 * user-interface elements are shown on primary outputs.
	 * @param primary request set this output as primary or secondary
	 */
	void (*primary)(struct wl_client *client,
			struct wl_resource *resource,
			struct wl_resource *output,
			int32_t primary);
	/**
	 * change output mode
	 *
	 * Sets the mode for a given output by its mode size (width and
	 * height) and refresh rate.
	 * @param output output this mode change applies to
	 * @param mode_id aspired mode's id
	 */
	void (*mode)(struct wl_client *client,
		     struct wl_resource *resource,
		     struct wl_resource *output,
		     int32_t mode_id);
	/**
	 * Transform outputdevice
	 *
	 * Sets the transformation for a given output.
	 * @param output output this transformation change applies to
	 * @param transform transform enum
	 */
	void (*transform)(struct wl_client *client,
			  struct wl_resource *resource,
			  struct wl_resource *output,
			  int32_t transform);
	/**
	 * Position output relative to global
	 *
	 * Sets the position for this output device in the global space.
	 * position describes the top-left border of the output in the
	 * global space. The left-most output's top-left border is 0, 0.
	 * There may be no gaps between outputs, the outputs have to be
	 * positioned stacked horizontally, vertically, or both.
	 * @param output output this position applies to
	 * @param x position on the x-axis
	 * @param y position on the y-axis
	 */
	void (*position)(struct wl_client *client,
			 struct wl_resource *resource,
			 struct wl_resource *output,
			 int32_t x,
			 int32_t y);
	/**
	 * Set the scaling factor for this outputdevice
	 *
	 * Sets the scaling factor for this outputdevice.
	 * @param output output this mode change applies to
	 * @param scale scaling factor
	 */
	void (*scale)(struct wl_client *client,
		      struct wl_resource *resource,
		      struct wl_resource *output,
		      int32_t scale);
	/**
	 * apply the changes to the outputs
	 *
	 * Asks the compositor to apply changes to the outputs on the
	 * server side.
	 */
	void (*apply)(struct wl_client *client,
		      struct wl_resource *resource);
};

#define GREENISLAND_OUTPUTCONFIGURATION_APPLIED 0
#define GREENISLAND_OUTPUTCONFIGURATION_FAILED 1

/**
 * @ingroup iface_greenisland_outputconfiguration
 */
#define GREENISLAND_OUTPUTCONFIGURATION_APPLIED_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_outputconfiguration
 */
#define GREENISLAND_OUTPUTCONFIGURATION_FAILED_SINCE_VERSION 1

/**
 * @ingroup iface_greenisland_outputconfiguration
 */
#define GREENISLAND_OUTPUTCONFIGURATION_ENABLE_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_outputconfiguration
 */
#define GREENISLAND_OUTPUTCONFIGURATION_PRIMARY_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_outputconfiguration
 */
#define GREENISLAND_OUTPUTCONFIGURATION_MODE_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_outputconfiguration
 */
#define GREENISLAND_OUTPUTCONFIGURATION_TRANSFORM_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_outputconfiguration
 */
#define GREENISLAND_OUTPUTCONFIGURATION_POSITION_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_outputconfiguration
 */
#define GREENISLAND_OUTPUTCONFIGURATION_SCALE_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_outputconfiguration
 */
#define GREENISLAND_OUTPUTCONFIGURATION_APPLY_SINCE_VERSION 1

/**
 * @ingroup iface_greenisland_outputconfiguration
 * Sends an applied event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
greenisland_outputconfiguration_send_applied(struct wl_resource *resource_)
{
	wl_resource_post_event(resource_, GREENISLAND_OUTPUTCONFIGURATION_APPLIED);
}

/**
 * @ingroup iface_greenisland_outputconfiguration
 * Sends an failed event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
greenisland_outputconfiguration_send_failed(struct wl_resource *resource_)
{
	wl_resource_post_event(resource_, GREENISLAND_OUTPUTCONFIGURATION_FAILED);
}

#ifdef  __cplusplus
}
#endif

#endif
