/* Generated by wayland-scanner 1.12.0 */

#ifndef GREENISLAND_SCREENSHOOTER_SERVER_PROTOCOL_H
#define GREENISLAND_SCREENSHOOTER_SERVER_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

#ifdef  __cplusplus
extern "C" {
#endif

struct wl_client;
struct wl_resource;

/**
 * @page page_greenisland_screenshooter The greenisland_screenshooter protocol
 * @section page_ifaces_greenisland_screenshooter Interfaces
 * - @subpage page_iface_greenisland_screenshooter - dump the contents of an output, a surface or an area to a buffer
 * - @subpage page_iface_greenisland_screenshot - screenshot
 * @section page_copyright_greenisland_screenshooter Copyright
 * <pre>
 *
 * Copyright (C) 2015-2016 Pier Luigi Fiorini
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * </pre>
 */
struct greenisland_screenshooter;
struct greenisland_screenshot;
struct wl_buffer;
struct wl_output;

/**
 * @page page_iface_greenisland_screenshooter greenisland_screenshooter
 * @section page_iface_greenisland_screenshooter_desc Description
 *
 * This interface is used by programs to take a screenshot of an entire
 * output, a user-selected area or a specific surface.
 *
 * The client asks the compositor to capture with one of the capture
 * requests. As a result, a greenisland_screenshot object will be created
 * and the greenisland_screenshot.setup event will be sent as soon as the
 * client binds to the interface.
 *
 * See the documentation of greenisland_screencast for more details.
 * @section page_iface_greenisland_screenshooter_api API
 * See @ref iface_greenisland_screenshooter.
 */
/**
 * @defgroup iface_greenisland_screenshooter The greenisland_screenshooter interface
 *
 * This interface is used by programs to take a screenshot of an entire
 * output, a user-selected area or a specific surface.
 *
 * The client asks the compositor to capture with one of the capture
 * requests. As a result, a greenisland_screenshot object will be created
 * and the greenisland_screenshot.setup event will be sent as soon as the
 * client binds to the interface.
 *
 * See the documentation of greenisland_screencast for more details.
 */
extern const struct wl_interface greenisland_screenshooter_interface;
/**
 * @page page_iface_greenisland_screenshot greenisland_screenshot
 * @section page_iface_greenisland_screenshot_desc Description
 *
 * A screenshot allows a client to perform a capture of an entire output,
 * an area selected by a user-driven operation, the active window or a
 * specific surface.  Whatever is to be captured is decided by the capture
 * request that was called from the greenisland_screenshooter interface.
 *
 * The 'setup' event is sent as soon as the client binds to this interface
 * and indicates the size of the buffer that needs to be allocated.
 *
 * Invoking the 'capture' request triggers the actual capture.
 * The 'done' event is sent when the capture is done, at this point the
 * client can decide what to do with the buffer (store into a file, display
 * to the user, ...).
 * @section page_iface_greenisland_screenshot_api API
 * See @ref iface_greenisland_screenshot.
 */
/**
 * @defgroup iface_greenisland_screenshot The greenisland_screenshot interface
 *
 * A screenshot allows a client to perform a capture of an entire output,
 * an area selected by a user-driven operation, the active window or a
 * specific surface.  Whatever is to be captured is decided by the capture
 * request that was called from the greenisland_screenshooter interface.
 *
 * The 'setup' event is sent as soon as the client binds to this interface
 * and indicates the size of the buffer that needs to be allocated.
 *
 * Invoking the 'capture' request triggers the actual capture.
 * The 'done' event is sent when the capture is done, at this point the
 * client can decide what to do with the buffer (store into a file, display
 * to the user, ...).
 */
extern const struct wl_interface greenisland_screenshot_interface;

#ifndef GREENISLAND_SCREENSHOOTER_EFFECTS_ENUM
#define GREENISLAND_SCREENSHOOTER_EFFECTS_ENUM
/**
 * @ingroup iface_greenisland_screenshooter
 * effects of the screenshot
 *
 * The different effects for the screenshot.
 *
 * Desktop environments may extend this enum by taking up a range of
 * values and documenting the range they chose in this description.
 * They are not required to document the values for the range that they
 * chose. Ideally, any good extensions from a desktop environment should
 * make its way into standardization into this enum.
 *
 * The current reserved ranges are:
 *
 * 0x0000 - 0x0FFF: greenisland-screenshooter core values, documented below.
 */
enum greenisland_screenshooter_effects {
	/**
	 * include the pointer
	 */
	GREENISLAND_SCREENSHOOTER_EFFECTS_POINTER = 1,
	/**
	 * include the window border
	 */
	GREENISLAND_SCREENSHOOTER_EFFECTS_BORDER = 2,
};
#endif /* GREENISLAND_SCREENSHOOTER_EFFECTS_ENUM */

/**
 * @ingroup iface_greenisland_screenshooter
 * @struct greenisland_screenshooter_interface
 */
struct greenisland_screenshooter_interface {
	/**
	 * take a screenshot of an entire output
	 *
	 * Asks the compositor to capture an entire output.
	 * @param effects effects to apply for this capture
	 */
	void (*capture_output)(struct wl_client *client,
			       struct wl_resource *resource,
			       uint32_t id,
			       struct wl_resource *output,
			       struct wl_array *effects);
	/**
	 * take a screenshot of the active window
	 *
	 * Asks the compositor to take a screenshot of the active window.
	 * @param effects effects to apply for this capture
	 */
	void (*capture_active)(struct wl_client *client,
			       struct wl_resource *resource,
			       uint32_t id,
			       struct wl_array *effects);
	/**
	 * take a screenshot of a surface
	 *
	 * Asks the compositor to take a screenshot of a surface of a
	 * window selected by the user.
	 * @param effects effects to apply for this capture
	 */
	void (*capture_surface)(struct wl_client *client,
				struct wl_resource *resource,
				uint32_t id,
				struct wl_array *effects);
	/**
	 * take a screenshot of an area
	 *
	 * Asks the compositor to take a screenshot of an area. This
	 * request starts a user-driven selection of the area that will be
	 * captured.
	 * @param effects effects to apply for this capture
	 */
	void (*capture_area)(struct wl_client *client,
			     struct wl_resource *resource,
			     uint32_t id,
			     struct wl_array *effects);
};


/**
 * @ingroup iface_greenisland_screenshooter
 */
#define GREENISLAND_SCREENSHOOTER_CAPTURE_OUTPUT_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_screenshooter
 */
#define GREENISLAND_SCREENSHOOTER_CAPTURE_ACTIVE_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_screenshooter
 */
#define GREENISLAND_SCREENSHOOTER_CAPTURE_SURFACE_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_screenshooter
 */
#define GREENISLAND_SCREENSHOOTER_CAPTURE_AREA_SINCE_VERSION 1

#ifndef GREENISLAND_SCREENSHOT_ERROR_ENUM
#define GREENISLAND_SCREENSHOT_ERROR_ENUM
/**
 * @ingroup iface_greenisland_screenshot
 * greenisland_screenshot error values
 *
 * These errors are emitted with the 'failed' event when a
 * capture request fails.
 */
enum greenisland_screenshot_error {
	/**
	 * Buffer doesn't match requirements
	 */
	GREENISLAND_SCREENSHOT_ERROR_BAD_BUFFER = 0,
};
#endif /* GREENISLAND_SCREENSHOT_ERROR_ENUM */

/**
 * @ingroup iface_greenisland_screenshot
 * @struct greenisland_screenshot_interface
 */
struct greenisland_screenshot_interface {
	/**
	 * destroy greenisland_screenshot
	 *
	 * Destroy this greenisland_screenshot object.
	 */
	void (*destroy)(struct wl_client *client,
			struct wl_resource *resource);
	/**
	 * take a screenshot
	 *
	 * Ask the compositor to take a screenshot and save the contents
	 * into the buffer. What is being capture can be either an output,
	 * a surface or an area that was selected with user interaction,
	 * depending on the greenisland_screenshooter request that was
	 * invoked.
	 * @param buffer client buffer that will hold data
	 */
	void (*record)(struct wl_client *client,
		       struct wl_resource *resource,
		       struct wl_resource *buffer);
};

#define GREENISLAND_SCREENSHOT_SETUP 0
#define GREENISLAND_SCREENSHOT_DONE 1
#define GREENISLAND_SCREENSHOT_FAILED 2

/**
 * @ingroup iface_greenisland_screenshot
 */
#define GREENISLAND_SCREENSHOT_SETUP_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_screenshot
 */
#define GREENISLAND_SCREENSHOT_DONE_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_screenshot
 */
#define GREENISLAND_SCREENSHOT_FAILED_SINCE_VERSION 1

/**
 * @ingroup iface_greenisland_screenshot
 */
#define GREENISLAND_SCREENSHOT_DESTROY_SINCE_VERSION 1
/**
 * @ingroup iface_greenisland_screenshot
 */
#define GREENISLAND_SCREENSHOT_RECORD_SINCE_VERSION 1

/**
 * @ingroup iface_greenisland_screenshot
 * Sends an setup event to the client owning the resource.
 * @param resource_ The client's resource
 * @param width width of the frame, in pixels
 * @param height height of the frame, in pixels
 * @param stride stride of the buffer
 * @param format format of the buffer
 */
static inline void
greenisland_screenshot_send_setup(struct wl_resource *resource_, int32_t width, int32_t height, int32_t stride, int32_t format)
{
	wl_resource_post_event(resource_, GREENISLAND_SCREENSHOT_SETUP, width, height, stride, format);
}

/**
 * @ingroup iface_greenisland_screenshot
 * Sends an done event to the client owning the resource.
 * @param resource_ The client's resource
 */
static inline void
greenisland_screenshot_send_done(struct wl_resource *resource_)
{
	wl_resource_post_event(resource_, GREENISLAND_SCREENSHOT_DONE);
}

/**
 * @ingroup iface_greenisland_screenshot
 * Sends an failed event to the client owning the resource.
 * @param resource_ The client's resource
 * @param error error that has occurred
 */
static inline void
greenisland_screenshot_send_failed(struct wl_resource *resource_, int32_t error)
{
	wl_resource_post_event(resource_, GREENISLAND_SCREENSHOT_FAILED, error);
}

#ifdef  __cplusplus
}
#endif

#endif
